 # -*- coding: utf-8 -*-
from thumbor.config import Config

Config.define(
        'TC_MULTIDIR_PATHS',
        [],
        'The list of paths where the File Loader will try to find images',
        'File Loader'
)


#!/usr/bin/python
# -*- coding: utf-8 -*-

from os import fstat
from datetime import datetime
from os.path import join, exists, abspath

from tornado.concurrent import return_future

from thumbor.loaders import LoaderResult
from thumbor.utils import logger

@return_future
def load(context, path, callback):

    for idx, next_dir in enumerate(context.config.TC_MULTIDIR_PATHS):

        file_path = join(next_dir.rstrip('/'), path.lstrip('/'))
        file_path = abspath(file_path)

        inside_root_path = file_path.startswith(abspath(next_dir))

        if inside_root_path and exists(file_path):
            with open(file_path, 'rb') as f:
                stats = fstat(f.fileno())

                result = LoaderResult()
                result.successful = True
                result.buffer = f.read()

                result.metadata.update(
                    size=stats.st_size,
                    updated_at=datetime.utcfromtimestamp(stats.st_mtime))
            callback(result)
            return

        logger.debug('TC_MULTIDIR: File {0} not found in {1}'.format(path, next_dir))
        # else loop and try next directory
    
    if not context.config.TC_MULTIDIR_PATHS:
        logger.error('TC_MULTIDIR: No paths set in configuration TC_MULTIDIR_PATHS')

    # no file found
    result.error = LoaderResult.ERROR_NOT_FOUND
    result.successful = False
    callback(result)



# coding: utf-8

from setuptools import setup, find_packages



def readme():
    with open('README.md') as f:
        return f.read()


setup(
    name='thumbor_multidir',
    version='0.2.2',
    description="Thumbor file loader for multiple paths",
    keywords='imaging face detection feature thumbor file loader',
    author='Benn Eichhorn',
    author_email='beichhor@gmail.com',
    url='https://github.com/benneic/thumbor_multidir',
    license='MIT',
    classifiers=['Development Status :: 5 - Production/Stable',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: MIT License',
                 'Natural Language :: English',
                 'Operating System :: MacOS',
                 'Operating System :: POSIX :: Linux',
                 'Programming Language :: Python :: 2.7',
                 'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
                 'Topic :: Multimedia :: Graphics :: Presentation'],
    zip_safe=False,
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'python-dateutil',
        'thumbor>=6.0.0,<7',
    ],
    extras_require={
    },
    long_description=readme(),
)